# Bayesian Network

Public library for a Bayesian Network in python. This library uses only `re` as dependency. It works as a standalone library and can be used in any python project.

It is defined as a class `BayesNetwork` which has the following methods:

* `add_node` : Adds a node to the network
* `edit_node` : Edits a node in the network
* `compact` : Shows a compact representation of the network
* `defined` : Checks if every node is defined
* `query` : Queries the network for a given node

## Installation
```bash
pip install memebayes
```
## Usage

```python
```



